# Welcome to Stochastic Matching's documentation!

:::{toctree}
:maxdepth: 2
:caption: Contents:

presentation
tutorials/index
companion/index
reference/index
:::

# Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
